==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dd/dea/group__cmd_8cpp.js <==
var group__cmd_8cpp =
[
    [ "AddVehicleToGroup", "dd/dea/group__cmd_8cpp.html#ade407404d7f7485810c825a36ce9168f", null ],
    [ "CmdAddSharedVehicleGroup", "dd/dea/group__cmd_8cpp.html#acc3c8a3d2a4aa504520f297000a4860c", null ],
    [ "CmdAddVehicleGroup", "dd/dea/group__cmd_8cpp.html#aaab50950b98c6d12940f45c54258d890", null ],
    [ "CmdAlterGroup", "dd/dea/group__cmd_8cpp.html#a83fdd456cf95f3ceadecd95cd78253b8", null ],
    [ "CmdCreateGroup", "dd/dea/group__cmd_8cpp.html#ac5a33adf427e2f752da2f0532a735d00", null ],
    [ "CmdDeleteGroup", "dd/dea/group__cmd_8cpp.html#a6ce75b3c59c1ec6071d3038e09ed8681", null ],
    [ "CmdRemoveAllVehiclesGroup", "dd/dea/group__cmd_8cpp.html#a0e7f3b59ed92d24be11a9571a75e6221", null ],
    [ "CmdSetGroupLivery", "dd/dea/group__cmd_8cpp.html#a9ff7a2825727cfba61d5450c876a3438", null ],
    [ "CmdSetGroupReplaceProtection", "dd/dea/group__cmd_8cpp.html#a9b53c9eeb6bd449e25c75cef106498dd", null ],
    [ "GetGroupNumEngines", "dd/dea/group__cmd_8cpp.html#aa4c669f5e826b31dd2150e1856469e47", null ],
    [ "GetParentLivery", "dd/dea/group__cmd_8cpp.html#aa5993d30e9e94e0216c46106f91b99a9", null ],
    [ "GroupIsInGroup", "dd/dea/group__cmd_8cpp.html#af6bbd0ee2d4e988b49ef97b74232ea2b", null ],
    [ "IsUniqueGroupNameForVehicleType", "dd/dea/group__cmd_8cpp.html#a6a3f3184b367a9e3c30743b2aa0953cd", null ],
    [ "PropagateChildLivery", "dd/dea/group__cmd_8cpp.html#a8f7ea3ad9df4853b20b3d5f0a946f944", null ],
    [ "RemoveAllGroupsForCompany", "dd/dea/group__cmd_8cpp.html#af59cb633adffbbfe4eaaf54f64073cf6", null ],
    [ "RemoveVehicleFromGroup", "dd/dea/group__cmd_8cpp.html#addaa28ca73c738a09c73897c83424967", null ],
    [ "SetGroupReplaceProtection", "dd/dea/group__cmd_8cpp.html#a03299706b80e989cacf2d7be07aed442", null ],
    [ "SetTrainGroupID", "dd/dea/group__cmd_8cpp.html#a68d2f101e1d06388e38afddcce8ef8de", null ],
    [ "UpdateNumEngineGroup", "dd/dea/group__cmd_8cpp.html#ac073323fcf653392cc872f0a17899ddf", null ],
    [ "UpdateTrainGroupID", "dd/dea/group__cmd_8cpp.html#a8b0b4425cfd1bbfe01d0d2dc7c628a83", null ],
    [ "_group_pool", "dd/dea/group__cmd_8cpp.html#af914b757569f04d054640783b87b5313", null ],
    [ "_new_group_id", "dd/dea/group__cmd_8cpp.html#a22f2115a278ada153509a61829ef8c63", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dd/dea/group__cmd_8cpp.js <==
var group__cmd_8cpp =
[
    [ "AddVehicleToGroup", "dd/dea/group__cmd_8cpp.html#ade407404d7f7485810c825a36ce9168f", null ],
    [ "CmdAddSharedVehicleGroup", "dd/dea/group__cmd_8cpp.html#acc3c8a3d2a4aa504520f297000a4860c", null ],
    [ "CmdAddVehicleGroup", "dd/dea/group__cmd_8cpp.html#aaab50950b98c6d12940f45c54258d890", null ],
    [ "CmdAlterGroup", "dd/dea/group__cmd_8cpp.html#a83fdd456cf95f3ceadecd95cd78253b8", null ],
    [ "CmdCreateGroup", "dd/dea/group__cmd_8cpp.html#ac5a33adf427e2f752da2f0532a735d00", null ],
    [ "CmdDeleteGroup", "dd/dea/group__cmd_8cpp.html#a6ce75b3c59c1ec6071d3038e09ed8681", null ],
    [ "CmdRemoveAllVehiclesGroup", "dd/dea/group__cmd_8cpp.html#a0e7f3b59ed92d24be11a9571a75e6221", null ],
    [ "CmdSetGroupLivery", "dd/dea/group__cmd_8cpp.html#a9ff7a2825727cfba61d5450c876a3438", null ],
    [ "CmdSetGroupReplaceProtection", "dd/dea/group__cmd_8cpp.html#a9b53c9eeb6bd449e25c75cef106498dd", null ],
    [ "GetGroupNumEngines", "dd/dea/group__cmd_8cpp.html#aa4c669f5e826b31dd2150e1856469e47", null ],
    [ "GetGroupNumProfitVehicle", "dd/dea/group__cmd_8cpp.html#addc5f16a2312f4c1cfb906fae84a1bd3", null ],
    [ "GetGroupNumVehicle", "dd/dea/group__cmd_8cpp.html#aef1138c081c19bf07d51d6a98aa67444", null ],
    [ "GetGroupProfitLastYear", "dd/dea/group__cmd_8cpp.html#a5701b978cf095320f1342a469e4318a0", null ],
    [ "GetParentLivery", "dd/dea/group__cmd_8cpp.html#aa5993d30e9e94e0216c46106f91b99a9", null ],
    [ "GroupIsInGroup", "dd/dea/group__cmd_8cpp.html#af6bbd0ee2d4e988b49ef97b74232ea2b", null ],
    [ "PropagateChildLivery", "dd/dea/group__cmd_8cpp.html#a8f7ea3ad9df4853b20b3d5f0a946f944", null ],
    [ "RemoveAllGroupsForCompany", "dd/dea/group__cmd_8cpp.html#af59cb633adffbbfe4eaaf54f64073cf6", null ],
    [ "RemoveVehicleFromGroup", "dd/dea/group__cmd_8cpp.html#addaa28ca73c738a09c73897c83424967", null ],
    [ "SetGroupReplaceProtection", "dd/dea/group__cmd_8cpp.html#a03299706b80e989cacf2d7be07aed442", null ],
    [ "SetTrainGroupID", "dd/dea/group__cmd_8cpp.html#a68d2f101e1d06388e38afddcce8ef8de", null ],
    [ "UpdateNumEngineGroup", "dd/dea/group__cmd_8cpp.html#ac073323fcf653392cc872f0a17899ddf", null ],
    [ "UpdateTrainGroupID", "dd/dea/group__cmd_8cpp.html#a8b0b4425cfd1bbfe01d0d2dc7c628a83", null ],
    [ "_group_pool", "dd/dea/group__cmd_8cpp.html#af914b757569f04d054640783b87b5313", null ],
    [ "_new_group_id", "dd/dea/group__cmd_8cpp.html#a22f2115a278ada153509a61829ef8c63", null ]
];
